aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_gfx_element.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-04-17 21:08:42 -0400
committerPaul Gilbert2016-07-10 16:11:21 -0400
commit46a30255b0e5a7f5dad4fd032388d31a69208b62 (patch)
tree1e668339aecb1246c9ec20515b81866d81ab75d2 /engines/titanic/pet_control/pet_gfx_element.h
parenta11e677494d7cb3c6b8ed2c56095873d46a00ab8 (diff)
downloadscummvm-rg350-46a30255b0e5a7f5dad4fd032388d31a69208b62.tar.gz
scummvm-rg350-46a30255b0e5a7f5dad4fd032388d31a69208b62.tar.bz2
scummvm-rg350-46a30255b0e5a7f5dad4fd032388d31a69208b62.zip
TITANIC: Seperate PET classes setup and reset methods
Diffstat (limited to 'engines/titanic/pet_control/pet_gfx_element.h')
-rw-r--r--engines/titanic/pet_control/pet_gfx_element.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/titanic/pet_control/pet_gfx_element.h b/engines/titanic/pet_control/pet_gfx_element.h
index a4c39c6d24..bc9150e04c 100644
--- a/engines/titanic/pet_control/pet_gfx_element.h
+++ b/engines/titanic/pet_control/pet_gfx_element.h
@@ -43,9 +43,9 @@ public:
CPetControl *petControl);
/**
* Setup the element
*/
- virtual void setup(const CString &name, CPetControl *petControl, PetElementMode mode);
+ virtual void reset(const CString &name, CPetControl *petControl, PetElementMode mode);
/**
* Draw the item
@@ -43,9 +43,9 @@ public:
CPetControl *petControl);
/**
- * Setup the element
+ * Reset the element
*/